@@ -120,9 +120,7 @@ typedef enum
     EXTEND_NONE = CAIRO_EXTEND_NONE,
     EXTEND_REPEAT = CAIRO_EXTEND_REPEAT,
     EXTEND_REFLECT = CAIRO_EXTEND_REFLECT,
-#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1,1,1)
     EXTEND_PAD = CAIRO_EXTEND_PAD
-#endif /* CAIRO_VERSION > CAIRO_VERSION_ENCODE(1,1,1) */
 } Extend;
 
 
@@ -176,7 +174,9 @@ typedef enum
     SURFACE_TYPE_BEOS = CAIRO_SURFACE_TYPE_BEOS,
     SURFACE_TYPE_DIRECTFB = CAIRO_SURFACE_TYPE_DIRECTFB,
     SURFACE_TYPE_SVG = CAIRO_SURFACE_TYPE_SVG,
-    SURFACE_TYPE_OS2 = CAIRO_SURFACE_TYPE_OS2
+    SURFACE_TYPE_OS2 = CAIRO_SURFACE_TYPE_OS2,
+    SURFACE_TYPE_WIN32_PRINTING = CAIRO_SURFACE_TYPE_WIN32_PRINTING,
+    SURFACE_TYPE_QUARTZ_IMAGE = CAIRO_SURFACE_TYPE_QUARTZ_IMAGE
 } SurfaceType;
 
 typedef enum
