@@ -94,6 +94,18 @@ SurfaceType Surface::get_type() const
   return static_cast<SurfaceType>(surface_type);
 }
 
+void Surface::copy_page()
+{
+  cairo_surface_copy_page(m_cobject);
+  check_object_status_and_throw_exception(*this);
+}
+
+void Surface::show_page()
+{
+  cairo_surface_show_page(m_cobject);
+  check_object_status_and_throw_exception(*this);
+}
+
 #ifdef CAIRO_HAS_PNG_FUNCTIONS
 void Surface::write_to_png(const std::string& filename)
 {
@@ -202,6 +214,11 @@ int ImageSurface::get_stride() const
   return cairo_image_surface_get_stride(m_cobject);
 }
 
+int ImageSurface::format_stride_for_width (Cairo::Format format, int width)
+{
+  return cairo_format_stride_for_width(static_cast<cairo_format_t>(format), width);
+}
+
 
 /*******************************************************************************
  * THE FOLLOWING SURFACE TYPES ARE EXPERIMENTAL AND NOT FULLY SUPPORTED
@@ -293,6 +310,39 @@ void PsSurface::dsc_begin_page_setup()
   check_object_status_and_throw_exception(*this);
 }
 
+void PsSurface::set_eps(bool eps)
+{
+  cairo_ps_surface_set_eps(m_cobject, eps);
+  check_object_status_and_throw_exception(*this);
+}
+
+void PsSurface::restrict_to_level(PsLevel level)
+{
+  cairo_ps_surface_restrict_to_level(m_cobject, static_cast<cairo_ps_level_t>(level));
+  check_object_status_and_throw_exception(*this);
+}
+
+const std::vector<PsLevel> PsSurface::get_levels()
+{
+  cairo_ps_level_t const *levels;
+  int num_levels;
+  cairo_ps_get_levels(&levels, &num_levels);
+
+  // Just copy the level array out into a std::vector.  This is a rarely used
+  // function and the array of levels is going to be very small, so there's no
+  // real performance hit.
+  std::vector<PsLevel> vec;
+  for (int i = 0; i < num_levels; ++i)
+  {
+    vec.push_back(static_cast<PsLevel>(levels[i]));
+  }
+  return vec;
+}
+
+std::string PsSurface::level_to_string(PsLevel level)
+{
+  return std::string(cairo_ps_level_to_string(static_cast<cairo_ps_level_t>(level)));
+}
 
 #endif // CAIRO_HAS_PS_SURFACE
 
